@@ -163,13 +163,19 @@ class DataFileProperty:
 
     def _load(self, start_end_fun, total=100):
         for i in range(1, total):
-            self.file_pro.start_date, self.file_pro.end_date = start_end_fun(-i)
-            self._daily_load_and_save(self.file_pro)
+            try:
+                self.file_pro.start_date, self.file_pro.end_date = start_end_fun(-i)
+                self._daily_load_and_save(self.file_pro)
+            except Exception as e:
+                print(e)
 
     def _merge(self, start_end_fun, total=10):
         for i in range(1, total):
-            self.file_pro.start_date, self.file_pro.end_date = start_end_fun(-i)
-            self._merge_and_save(self.file_pro)
+            try:
+                self.file_pro.start_date, self.file_pro.end_date = start_end_fun(-i)
+                self._merge_and_save(self.file_pro)
+            except Exception as e:
+                print(e)
 
     def load(self, total=100):
         if self.file_pro.freq == 'daily':
