@@ -2,10 +2,10 @@
 import pymysql
 from notetool.secret import read_secret
 
-host = read_secret(cate1="database", cate2="mysql", cate3="host")
-user = read_secret(cate1="database", cate2="mysql", cate3="user")
-password = read_secret(cate1="database", cate2="mysql", cate3="password")
-database = read_secret(cate1="database", cate2="mysql", cate3="database")
+host = read_secret(cate1="notecoin", cate2="database", cate3="mysql", cate4='host')
+database = read_secret(cate1="notecoin", cate2="database", cate3="mysql", cate4='database')
+user = read_secret(cate1="notecoin", cate2="database", cate3="mysql", cate4='user')
+password = read_secret(cate1="notecoin", cate2="database", cate3="mysql", cate4='password')
 
 
 def create_database(database=None):
